==> haskell-coinbase-pro-0.9.3.2-389-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-AcTApsILXTFIwCipld80lL
key:                  coinbase-pro-0.9.3.2-AcTApsILXTFIwCipld80lL
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  10060ae71fb997518e7ca6ce81dc55fd
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-AcTApsILXTFIwCipld80lL
depends:
    HsOpenSSL-0.11.7.9-AP7ashMRPIw3FC8bY0gpOj
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    aeson-casing-0.2.0.0-1MsK1kFNrc34lk34lhwg22
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-J05HlVSc5IIHLQ8uVby8as exceptions-0.10.5
    http-api-data-0.6.1-FahDGTMw50P4NKEAb3IwkU
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
    http-streams-0.8.9.9-H6fKxnbMrwTGPcGztXB1x3
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    io-streams-1.5.2.2-HTsZjq0uxoOIVNehfMFaNS
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    servant-0.20.3.0-GOIaCeayVrDJ22GgZs5cgj
    servant-client-0.20.3.0-5s7zGzfAItOB4ZzFrtUduz
    servant-client-core-0.20.3.0-ElEnQUK02Oe3ydbQ9eDBFI
    tasty-1.5-BVD6jS8MYMXHx1dDlDXdd2
    tasty-hunit-0.10.2-EW3UORbab3JJyhoumRdA8U text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-DHMF6k2keHc8OMuHbl92Kw
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    uuid-1.3.16-EjkwI8O9b0QEIoqIovpB87
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    websockets-0.12.7.3-JCxuSwfRFoa2kMJGXPl9F7
    wuss-2.0.1.5-DDFcqlgOsv9HPUkEuer8fd

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-419-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-HVVYpfv5wMA6TcqZayksXy
key:                  coinbase-pro-0.9.3.2-HVVYpfv5wMA6TcqZayksXy
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  c1bc7188b972abdf562125f6eefcf5dd
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-HVVYpfv5wMA6TcqZayksXy
depends:
    HsOpenSSL-0.11.7.9-5wP7EphUuc2FrdkjtkCzRk
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    aeson-casing-0.2.0.0-16LXXNasBe18qw8QL5r9dJ
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-5T9hA5iejCiIzteqbNsY1m exceptions-0.10.5
    http-api-data-0.6.1-Ct3YGnpgXQS6uC3vp2y6CM
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-streams-0.8.9.9-1xcnfCdIwCOGL2p8snsF8b
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    io-streams-1.5.2.2-CqhNECtx3ZHFkLKvc41w22
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    servant-0.20.3.0-5yfHPrFnFIjC5udvdKPgHT
    servant-client-0.20.3.0-FQJcxzQHMgZ43pa5N5fjmb
    servant-client-core-0.20.3.0-168OqtrGYus1cDAOzzAo5H
    tasty-1.5.2-BKpN9d8J2hIHwcKpwM8zsO
    tasty-hunit-0.10.2-KQQ8gauHRJMLeGTwOTr3bh text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-HmMURs9dV0HBJs4l7cajvZ
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    uuid-1.3.16-7LbW7JPPUccGPBdJigsSEH
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    websockets-0.12.7.3-K1euWosJ016LvWNLf07xvL
    wuss-2.0.1.6-GEBE45y7G9A5he6enFGGJW

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
